<!--隐患查询-修改弹层-->
<template>
  <!-- 弹出框 -->
  <van-popup
    position="bottom"
    :style="{height: '77%', width: '100%'}"
    v-model="isShowPopup"
    class="popup"
    closeable
  >
    <div class="popup-content">
      <div class="title">隐患详情</div>
      <van-form label-align="right">
        <div class="hidden-trouble">
          <div class="trouble-content">
            <div>
              <van-field
                readonly
                clickable
                name="datetimePicker"
                :value="detailListFrom.checkDate"
                label="隐患发现时间"
                placeholder="点击选择时间"
                @click="showPicker = true"
              />
              <van-popup v-model="showPicker" position="bottom">
                <van-datetime-picker
                  type="date"
                  @confirm="onConfirm"
                  @cancel="showPicker = false"
                />
              </van-popup>
              <van-field
                v-model="detailListFrom.dangerContent"
                name="隐患内容"
                label="隐患内容"
                placeholder="请输入隐患内容"
                :rules="[{required: true, message: '请填写隐患内容'}]"
              />
              <van-field
                v-model="detailListFrom.reformSugguest"
                name="整改措施建议"
                label="整改措施建议"
                placeholder="请输入整改措施建议"
              />
              <van-field
                v-model="detailListFrom.reference"
                name="参考依据说明"
                label="参考依据说明"
                placeholder="请输入参考依据说明"
              />
              <van-field name="uploader" label="隐患图片">
                <template #input>

                  <el-upload
                    accept="image/*"
                    name="files"
                    :action="uploadUrl"
                    :headers="header"
                    :data="{bizCode: 'Image', bizId: ''}"
                    :on-success="
                        (response, file, fileList) => {
                          return handleAvatarSuccess(response, file, fileList)
                        }
                      "
                    :before-upload="beforeAvatarUpload"
                    list-type="picture-card"
                    :on-remove="
                        (file, fileList) => {
                          return handleRemove(file, fileList)
                        }
                      "
                    :file-list="convertImg(detailListFrom.imgUrlArray)"
                  >
                    <i slot="default" class="el-icon-plus" />
                  </el-upload>
                </template>
              </van-field>
              <van-field name="uploader" label="整改后图片">
                <template #input>
                  <el-upload
                    name="files"
                    :action="uploadUrl"
                    :headers="header"
                    accept="image/*"
                    :data="{bizCode: 'Image', bizId: ''}"
                    :on-success="
                        (response, file, fileList) => {
                          return handleAvatarSuccess1(response, file, fileList)
                        }
                      "
                    :before-upload="beforeAvatarUpload"
                    list-type="picture-card"
                    :on-remove="
                        (file, fileList) => {
                          return handleRemove1(file, fileList)
                        }
                      "
                    :file-list="convertImg(detailListFrom.reformImgUrlArray)"
                  >
                    <i slot="default" class="el-icon-plus" />
                  </el-upload>
                </template>
              </van-field>
            </div>
          </div>
        </div>

        <div class="confirm-button" style="margin: 16px;">
          <van-button
            class="btn-left"
            round
            type="info"
            block
            plain
            native-type="button"
            @click="isShowPopup = false"
          >取消
          </van-button>
          <van-button
            class="btn-right"
            round
            block
            type="info"
            native-type="submit"
            @click="reviseBtn"
          >保存
          </van-button
          >
        </div>
      </van-form>
    </div>
  </van-popup>
</template>

<script>
import moment from 'moment'
import CmgtSaftyDangerCheckrecordApi from '@/views/Manage/saftyDanger/api/CmgtSaftyDangerCheckrecordApi'
import {mapState} from 'vuex'

const {
  getHiddenDangerDetails,
  CSaftyDangerCheckrecordDetailUpdateById
} = CmgtSaftyDangerCheckrecordApi

export default {
  name: 'ModifyPopup', // 隐患查询-修改弹层
  props: {
    // 是否展示弹层
    modifyPopup: {
      default: false,
      type: Boolean
    },
    rowInfo: {
      default() {
        return {}
      },
      type: Object
    }
  },
  data() {
    return {
      detailListFrom: {
        checkRecordId: null,
        unitId: null,
        reformImgUrlArray: [],
        imgUrlArray: [],
        checkDate: null,
        dangerContent: null,
        reformSugguest: null,
        reference: null,
        id: null
      },
      reviseShow: false,
      uploadUrl: window.context.portal + '/file/v1/uploadFileForConfig', // 服务器上传地址
      previewUrl:
        window.context.portal + '/file/onlinePreviewController/v1/getFileById_',
      showPicker: false

    }
  },
  computed: {
    isShowPopup: {
      get() {
        return this.modifyPopup
      },
      set(val) {
        this.$emit('update:modifyPopup', val)
      }
    },
    ...mapState({
      header(state) {
        return {
          Authorization: `Bearer ${state.login.currentUser.token}`
        }
      }
    })
  },
  methods: {
    moment,

    // 获取表单详情
    async getDetail(rowInfo, callback) {
      const {id} = rowInfo
      const {data: {value}} = await getHiddenDangerDetails(id)
      this.detailListFrom = {
        ...value,
        imgUrlArray: value.imgUrlArray ? value.imgUrlArray : []
      }
      callback && callback(this.detailListFrom)
    },

    handleAvatarSuccess1(res) {
      if (!res.success) return this.$message.error('上传文件失败！')
      let {reformImgUrlArray} = this.detailListFrom
      reformImgUrlArray = reformImgUrlArray.concat([res.fileId])
    },

    //确认
    reviseBtn() {
      CSaftyDangerCheckrecordDetailUpdateById(
        this.detailListFrom,
        _ => {
          this.$toast.success('修改成功')
          this.$emit('changeData', this.rowInfo)
        }
      )
    },

    // 图片转换
    convertImg(arr) {
      if (!(Array.isArray(arr) && arr.length)) return []
      return arr.map(it => {
        return {url: this.previewUrl + it, id: it}
      })
    },

    beforeAvatarUpload(file) {
      const isJPG =
        file.type === 'image/jpeg' ||
        file.type === 'image/png' ||
        file.type === 'image/jpg'
      const isLt10M = file.size / 1024 / 1024 < 10
      if (!isJPG) {
        this.$message.error('上传图片只能是 JPG 格式!')
      }
      if (!isLt10M) {
        this.$message.error('上传图片大小不能超过 10MB!')
      }
      return isJPG && isLt10M
    },

    handleAvatarSuccess(res) {
      if (res.success) {
        let arr = []
        arr.push(res.fileId)
        this.detailListFrom.imgUrlArray = this.detailListFrom.imgUrlArray.concat(
          arr
        )
      } else {
        this.$message.error('上传文件失败！')
      }
    },

    handleRemove(file) {
      this.detailListFrom.imgUrlArray.forEach((e, index) => {
        if (e === file.id) {
          this.detailListFrom.imgUrlArray.splice(index, 1)
        }
      })
    },

    handleRemove1(file) {
      this.detailListFrom.reformImgUrlArray.forEach((e, index) => {
        if (e === file.id) {
          this.detailListFrom.reformImgUrlArray.splice(index, 1)
        }
      })
    },

    onConfirm(date) {
      this.detailListFrom.checkDate = moment(date).format('YYYY-MM-DD')
      this.showPicker = false
    }

  }
}
</script>

<style lang="scss" scoped>
.popup-content {
  display: flex;
  flex-direction: column;
  height: 100%;
  background: #fff;

  .title {
    width: 100%;
    box-sizing: border-box;
    padding: 130px 0 100px 0;
    display: flex;
    align-items: center;
    justify-content: center;
    font-size: 80px;
  }

  .van-form {
    flex: 1;

    .confirm-button {
      display: flex;


      .van-button {
        flex: 1;
        margin: 0 !important;

        &.btn-left {
          border-radius: 999px 0 0 999px;
        }

        &.btn-right {
          border-radius: 0 999px 999px 0;
        }

        .van-button__text {
          font-size: 65px;
        }
      }


    }
  }

}
</style>

